# Scallop - quantitative evaluation of single-cell cluster memberships

**Master badges**
[![pipeline status](https://img.shields.io/gitlab/pipeline/alexmascension/scallop/master)](https://gitlab.com/alexmascension/scallop/commits/master)
[![Coverage report master](https://codecov.io/gl/alexmascension/scallop/branch/master/graph/badge.svg)](https://codecov.io/gl/alexmascension/scallop/branch/master)
[![Documentation Status Master](https://readthedocs.org/projects/scallop/badge/?version=latest)](https://scallop.readthedocs.io/en/latest/)
[![Pypi version](https://img.shields.io/pypi/v/scallop)](https://pypi.org/project/scallop/)

**Dev badges**
[![pipeline status](https://img.shields.io/gitlab/pipeline/alexmascension/scallop/dev)](https://gitlab.com/alexmascension/scallop/commits/dev)
[![Coverage report dev](https://codecov.io/gl/alexmascension/scallop/branch/dev/graph/badge.svg)](https://codecov.io/gl/alexmascension/scallop/branch/dev)


Scallop is a module for the evaluation of single-cell clustering solutions. 
It allows users to assess the quality of clustering using different
algorithms and parameter choices. 

Scallop provides users with a cell-wise robustness score based on bootstrap experiments, 
and a versatile plotting toolkit for visualization purposes. 

Scallop is meant to be used 
with annData objects from Scanpy. 
